elephant.change\_point\_detection.empirical\_parameters
=======================================================

.. currentmodule:: elephant.change_point_detection

.. autofunction:: empirical_parameters